@@ -16,41 +16,34 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-from safeeyes import utility
 from safeeyes.model import PluginDependency
+from safeeyes.translations import translate as _
 
 import gi
-gi.require_version('Gio', '2.0')
+
+gi.require_version("Gio", "2.0")
 from gi.repository import Gio
 
+
 def validate(plugin_config, plugin_settings):
     dbus_proxy = Gio.DBusProxy.new_for_bus_sync(
         bus_type=Gio.BusType.SESSION,
         flags=Gio.DBusProxyFlags.DO_NOT_LOAD_PROPERTIES,
         info=None,
-        name='org.freedesktop.DBus',
-        object_path='/org/freedesktop/DBus',
-        interface_name='org.freedesktop.DBus',
+        name="org.freedesktop.DBus",
+        object_path="/org/freedesktop/DBus",
+        interface_name="org.freedesktop.DBus",
         cancellable=None,
     )
 
-    if dbus_proxy.NameHasOwner('(s)', 'org.kde.StatusNotifierWatcher'):
+    if dbus_proxy.NameHasOwner("(s)", "org.kde.StatusNotifierWatcher"):
         return None
     else:
         return PluginDependency(
-            message=_("Please install service providing tray icons for your desktop environment."),
+            message=_(
+                "Please install service providing tray icons for your desktop"
+                " environment."
+            ),
             link="https://github.com/slgobinath/SafeEyes/wiki/How-to-install-backend-for-Safe-Eyes-tray-icon",
-            retryable=True
+            retryable=True,
         )
-
-    command = None
-    if utility.IS_WAYLAND:
-        if utility.DESKTOP_ENVIRONMENT == "gnome":
-            return None
-        command = "wlrctl"
-    else:
-        command = "xprop"
-    if not utility.command_exist(command):
-        return _("Please install the command-line tool '%s'") % command
-    else:
-        return None
